%define release_repository http://nexus.scala-tools.org/content/repositories/releases
%define snapshot_repository http://nexus.scala-tools.org/content/repositories/snapshots

%define fullversion %{version}.final
%define scaladir %{_datadir}/scala
%define with_system_jline 1
%global bits 32

%ifarch x86_64
  %global bits 64
%endif

%if %with_system_jline
%global jline2_jar /usr/share/java/jline2.jar
%endif
%global jansi_jar /usr/share/java/jansi.jar

Name:           scala
Version:        2.9.1
Release:        %mkrel 1
Summary:        A hybrid functional/object-oriented language for the JVM
Group:          Development/Java 
License:        BSD
URL:            http://www.scala-lang.org/
Source0:        http://www.scala-lang.org/downloads/distrib/files/scala-%{fullversion}-sources.tgz

Source21:       scala.keys
Source22:       scala.mime
Source23:       scala-mime-info.xml
Source24:       scala.ant.d

Source25:       scala-2.9.0.1-settings.xml

Patch1:         scala-2.9.1-use_system_jline.patch
Patch2:         scala-2.9.1-tooltemplate.patch
Patch3:         scala-2.9.1-use_system_ant-contrib.patch

# Force build with openjdk/icedtea because gij is horribly slow and I haven't
# been successful at integrating aot compilation with the build process
BuildRequires: java-1.6.0-openjdk-devel >= 0:1.6.0
BuildRequires: ant
# FIXME documentation dont build with ant 1.8.2
BuildRequires: ant17
BuildRequires: ant-contrib
#BuildRequires: ant-dotnet
BuildRequires: ant-nodeps
BuildRequires: hawtjni
BuildRequires: jansi
BuildRequires: jansi-native
%if %with_system_jline
BuildRequires: jline2 >= 2.5-2
%endif
BuildRequires: jpackage-utils
#BuildRequires: maven-ant-tasks
BuildRequires: shtool
BuildRequires: vizant
Requires:      java-1.6.0-openjdk
Requires:      hawtjni
Requires:      jansi
Requires:      jansi-native
%if %with_system_jline
Requires:      jline2 >= 2.5-2
%endif
Requires:      jpackage-utils


%description
Scala is a general purpose programming language designed to express common
programming patterns in a concise, elegant, and type-safe way. It smoothly
integrates features of object-oriented and functional languages. It is also
fully interoperable with Java.

%package apidoc
Summary:       Documentation for the Scala programming language
Group:         Development/Java
BuildArch:     noarch

%description apidoc
Scala is a general purpose programming language for the JVM that blends
object-oriented and functional programming. This package provides
reference and API documentation for the Scala programming language.

%package -n ant-scala
Summary:       Development files for Scala
Group:         Development/Java
Requires:      scala = %{version}-%{release}, ant
BuildArch:     noarch

%description -n ant-scala
Scala is a general purpose programming language for the JVM that blends
object-oriented and functional programming. This package enables support for
the scala ant tasks.

%package examples
Summary:       Examples for the Scala programming language
Group:         Development/Java
# Otherwise it will pick up some perl module
Autoprov:      0
Requires:      scala = %{version}-%{release}
BuildArch:     noarch

%description examples
Scala is a general purpose programming language for the JVM that blends
object-oriented and functional programming. This package contains examples for
the Scala programming language

%prep
%setup -q -n scala-%{fullversion}-sources
%patch1 -p1 -b .tool
%if %with_system_jline
%patch2 -p1 -b .sysjline
rm -rf src/jline
sed -i "s|jline.jar|jline2.jar|" build.xml
%endif
%patch3 -p0 -b .sysant-contrib

# remove all jar files except scala-library and scala-compiler needed
# for bootstrap
# find . -not \( -name 'scala-library.jar' -or -name 'scala-compiler.jar' -or -name 'msil.jar' -or -name 'fjbg.jar' -or -name 'forkjoin.jar' \) -and -name '*.jar' | xargs rm -f

find . -name '*.dll' -or -name '*.so' -or -name '*.exe' -or -name '*.bat' | xargs rm -f

pushd lib/ant
  rm -rf *.jar
#  ln -s $(build-classpath ant/ant-contrib) ant-contrib.jar
#  ln -s $(build-classpath ant/ant-dotnet) ant-dotnet-1.0.jar
  ln -s $(build-classpath ant17.jar) ant.jar
#  ln -s $(build-classpath maven-ant-tasks) maven-ant-tasks-2.1.1.jar
  ln -s $(build-classpath ant/vizant) vizant.jar
popd
rm -rf lib/jline.jar

%build
# Scala is written in itself and therefore requires boot-strapping from an
# initial binary build. The dist target of the ant build is a staged build
# that makes sure that the package bootstraps properly. The bundled binary
# compiler is used to compile the source code. That binary is used to
# compile the source code again. That binary is used to compile the code
# again and the output is checked that it is exactly the same. This makes
# sure that the build is repeatable and that the bootstrap compiler could
# be replaced with this one and successfully build the whole distribution
# again
%if !%with_system_jline
##
# Rebuild Bundled jline (require https://github.com/harrah/xsbt)
##

(
  cd src/jline/
  mkdir classes
  javac -d classes -cp $(build-classpath hawtjni-runtime jansi jansi-native) \
  -encoding iso-8859-1 \
  $(find src/main/java -name "*.java")
  cp -pr src/main/resources/scala/tools/jline/console/completer/CandidateListCompletionHandler.properties classes/scala/tools/jline/console/completer/
  jar cvf ../../lib/jline.jar -C classes .
  rm -rf classes
)

export CLASSPATH=$(build-classpath hawtjni-runtime jansi jansi-native):$PWD/lib/jline.jar
%endif
#define java_home %{_jvmdir}/java-openjdk
export ANT_OPTS="-Xms1024m -Xmx1024m"
# rebuild internal libraries and bootstrap compiler
#%ant -Dversion.number=%{fullversion} -Djava6.home=%{_jvmdir}/java-1.6.0 newlibs newforkjoin locker.clean pack.done starr.done locker.clean || exit 1


%ant -Dversion.number=%{fullversion} build
ant17 -Dpack.classpath=$PWD/build/pack/lib -Dversion.number=%{fullversion} docs

%install
rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_mandir}/man1 $RPM_BUILD_ROOT%{_bindir}
for prog in scaladoc fsc scala scalac scalap; do
        install -p -m 755 build/pack/bin/$prog $RPM_BUILD_ROOT%{_bindir}
        install -p -m 644 build/scaladoc/manual/man/man1/$prog.1 $RPM_BUILD_ROOT%{_mandir}/man1
done

install -p -m 755 -d $RPM_BUILD_ROOT%{_javadir}/scala
install -p -m 755 -d $RPM_BUILD_ROOT%{scaladir}/lib
for libname in scala-compiler scala-dbc scala-library scala-partest scala-swing scalap scalacheck ; do
        install -m 644 build/pack/lib/$libname.jar $RPM_BUILD_ROOT%{_javadir}/scala/$libname-%{fullversion}.jar
        ln -s $libname-%{fullversion}.jar $RPM_BUILD_ROOT%{_javadir}/scala/$libname.jar
        shtool mkln -s $RPM_BUILD_ROOT%{_javadir}/scala/$libname.jar $RPM_BUILD_ROOT%{scaladir}/lib
done
%if %with_system_jline
shtool mkln -s $RPM_BUILD_ROOT%{jline2_jar} $RPM_BUILD_ROOT%{scaladir}/lib/jline.jar
%else
install -m 644 lib/jline.jar $RPM_BUILD_ROOT%{_javadir}/scala/jline-%{fullversion}.jar
ln -s jline-%{fullversion}.jar $RPM_BUILD_ROOT%{_javadir}/scala/jline.jar
shtool mkln -s $RPM_BUILD_ROOT%{_javadir}/scala/jline.jar $RPM_BUILD_ROOT%{scaladir}/lib
%endif

install -p -m 755 -d $RPM_BUILD_ROOT%{scaladir}/misc/scala-devel/plugins
install -m 644 build/pack/misc/scala-devel/plugins/continuations.jar $RPM_BUILD_ROOT%{_javadir}/scala/continuations-%{fullversion}.jar
ln -s continuations-%{fullversion}.jar $RPM_BUILD_ROOT%{_javadir}/scala/continuations.jar
shtool mkln -s $RPM_BUILD_ROOT%{_javadir}/scala/continuations.jar $RPM_BUILD_ROOT%{scaladir}/misc/scala-devel/plugins

install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}
for p in scala-compiler scala-dbc scala-library scala-partest scala-swing scalap ; do
  install -pm 644 src/build/maven/$p-pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$p.pom
  sed -i "s|@VERSION@|%{fullversion}|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$p.pom
  sed -i "s|@RELEASE_REPOSITORY@|%release_repository|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$p.pom
  sed -i "s|@SNAPSHOT_REPOSITORY@|%snapshot_repository|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$p.pom
  %add_maven_depmap JPP.%{name}-$p.pom %{name}/$p.jar
done
install -pm 644 src/build/maven/continuations-plugin-pom.xml  $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-continuations.pom
sed -i "s|@VERSION@|%{fullversion}|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-continuations.pom
sed -i "s|@RELEASE_REPOSITORY@|%release_repository|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-continuations.pom
sed -i "s|@SNAPSHOT_REPOSITORY@|%snapshot_repository|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-continuations.pom
%add_maven_depmap JPP.%{name}-continuations.pom %{name}/continuations.jar

install -pm 644 src/build/maven/jline-pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-jline.pom
sed -i "s|@VERSION@|%{fullversion}|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-jline.pom
sed -i "s|@RELEASE_REPOSITORY@|%release_repository|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-jline.pom
sed -i "s|@SNAPSHOT_REPOSITORY@|%snapshot_repository|" $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-jline.pom

%if %with_system_jline
%add_to_maven_depmap org.scala-lang jline %{fullversion} JPP jline2
%else
%add_maven_depmap JPP.%{name}-jline.pom %{name}/jline.jar
%endif

%define hawtjnijar /usr/share/java/hawtjni-runtime.jar
shtool mkln -s  $RPM_BUILD_ROOT%hawtjnijar $RPM_BUILD_ROOT%{scaladir}/lib
shtool mkln -s  $RPM_BUILD_ROOT%jansi_jar $RPM_BUILD_ROOT%{scaladir}/lib
%define jansinativejar /usr/share/java-jni/jansi-native.jar
shtool mkln -s  $RPM_BUILD_ROOT%jansinativejar $RPM_BUILD_ROOT%{scaladir}/lib
%define jansinativearchjar %{_libdir}/java/jansi-native-linux%{bits}.jar
shtool mkln -s  $RPM_BUILD_ROOT%jansinativearchjar $RPM_BUILD_ROOT%{scaladir}/lib

install -d $RPM_BUILD_ROOT%{_sysconfdir}/ant.d
install -p -m 644 %{SOURCE24} $RPM_BUILD_ROOT%{_sysconfdir}/ant.d/scala

cp -pr docs/examples $RPM_BUILD_ROOT%{_datadir}/scala/

install -d $RPM_BUILD_ROOT%{_datadir}/mime-info
install -p -m 644 %{SOURCE21} %{SOURCE22} $RPM_BUILD_ROOT%{_datadir}/mime-info/

install -d $RPM_BUILD_ROOT%{_datadir}/mime/packages/
install -p -m 644 %{SOURCE23} $RPM_BUILD_ROOT%{_datadir}/mime/packages/

sed -i -e 's,@JAVADIR@,%{_javadir},g' -e 's,@DATADIR@,%{_datadir},g' $RPM_BUILD_ROOT%{_bindir}/*

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_bindir}/*
%{_javadir}/scala
%dir %{_datadir}/scala
%{_datadir}/scala/lib
%{_datadir}/scala/misc
%{_mandir}/man1/*
%doc docs/LICENSE
%doc README
%{_datadir}/mime-info/*
%{_datadir}/mime/packages/*
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*

%files -n ant-scala
# Following is plain config because the ant task classpath could change from
# release to release
%config %{_sysconfdir}/ant.d/*

%files apidoc
%doc build/scaladoc/library/*
%doc docs/LICENSE

%files examples
%{_datadir}/scala/examples



%changelog

* Mon Nov 28 2011 gil <gil> 2.9.1-1.mga2
+ Revision: 173763
- update to 2.9.1.final

* Mon Sep 05 2011 gil <gil> 2.9.0-1.mga2
+ Revision: 138819
- rebuilt with new jansi libraries
- update to 2.9.0.1

  + dmorgan <dmorgan>
    - Adapt to mageia guidelines

* Wed May 11 2011 pterjan <pterjan> 2.8.1-4.mga1
+ Revision: 97329
- Drop useless explicit filerequires, the package containing it is already required

* Wed May 11 2011 dmorgan <dmorgan> 2.8.1-3.mga1
+ Revision: 97225
- imported package scala


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec  9 2010 Jochen Schmitt <Jochen herr-schmitt de> - 2.8.1-1
- New upstream release (#661853)

* Sun Aug 15 2010 Geoff Reedy <geoff@programmer-monk.net> - 2.8.0-1
- Update to upstream 2.8.0 release

* Thu Oct 29 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.7-1
- Update to upstream 2.7.7 release

* Sat Sep 19 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.5-1
- Update to upstream 2.7.5 release

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon May 18 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.4-5
- fix problem in tooltemplate patch

* Mon May 18 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.4-4
- make jline implicitly available to match upstream behavior

* Mon May 18 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.4-3
- fix problem with substitutions to scripts in %%install

* Mon May 18 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.4-2
- fix launcher scripts by modifying template, not overriding them

* Tue May 12 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.4-1
- update to 2.7.4 final

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jan 21 2009 Geoff Reedy <geoff@programmer-monk.net> - 2.7.3-1
- update to 2.7.3 final

* Sun Nov 09 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.2-1
- update to 2.7.2 final

* Mon Nov 03 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.2-0.3.RC6
- bump release to fix upgrade path

* Thu Nov 01 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.2-0.1.RC6
- update to 2.7.2-RC6

* Thu Oct 30 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.2-0.1.RC5
- update to 2.7.2-RC5

* Sat Sep 06 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.2-0.2.RC1
- All code is now under BSD license
- Remove dll so and exe binaries in prep
- Add BuildRequires required by Java packaging guidelines
- Add missing defattr for examples and ant-scala

* Wed Aug 20 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.2-0.1.RC1
- update to 2.7.2-RC1

* Wed Aug 13 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.1-3
- regenerate classpath in manifest patch to apply cleanly to 2.7.1

* Wed Aug 13 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.1-2
- no changes, accidental release bump

* Mon May 05 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.1-1
- Update to 2.7.1

* Fri May 02 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.0-2
- Use java-sdk-openjdk for non-fc8 builds

* Mon Mar 10 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.7.0-1
- Update to 2.7.0
- License now correctly indicated as BSD and LGPLv2+
- Include LICENSE file in apidoc subpackage

* Mon Feb 11 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-8
- Adhere more strongly to the emacs package guidelines
- Include some comments regarding the boot-strapping process

* Wed Jan 16 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-7
- Add dist tag to release
- Fix directory ownership issues in %%_datadir/scala
- Remove source code from -devel package
- Rename -devel package to ant-scala
- Fix packaging of gtksourceview2 language spec
- Preserve timestamps when installing and cping
- Add patch to remove Class-Path entries from jar manifests
- Fix line endings in enscript/README
 
* Sun Jan 13 2008 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-6
- Include further information about inclusion of binary distribution
- Unpack only those files needed from the binary distribution
- Include note about license approval

* Thu Dec 27 2007 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-5
- Add emacs(bin) BR
- Patch out call to subversion in build.xml
- Add pkgconfig to BuildRequires

* Thu Dec 27 2007 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-4
- Reformat emacs-scala description
- Expand tabs to spaces
- Fix -devel symlinks
- Better base package summary

* Wed Dec 26 2007 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-3
- Add ant config to devel package
- Require icedtea for build
- Move examples to %%{_datadir}/scala/examples
- Clean up package descriptions
- Add base package requirement for scala-examples and scala-devel

* Wed Dec 26 2007 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-2
- Fix post scripts
- Use spaces instead of tabs

* Wed Dec 26 2007 Geoff Reedy <geoff@programmer-monk.net> - 2.6.1-1
- Initial build.
